#
# spec file for package wwwoffle
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           wwwoffle
Version:        2.9j
Release:        14.2
Summary:        World Wide Web Offline Proxy
License:        GPL-2.0+
Group:          Productivity/Networking/Web/Proxy
Url:            http://www.gedanken.org.uk/software/wwwoffle/
Source0:        http://www.gedanken.org.uk/software/%{name}/download/%{name}-%{version}.tgz
Source1:        %{name}.service
Source3:        ip-up.%{name}
Source4:        ip-down.%{name}
Source5:        %{name}.cron
Patch0:         %{name}-2.8d-IndexProtocol.diff
Patch1:         %{name}-2.9e-implicit.patch
Patch2:         %{name}-2.9e-res_init.diff
Patch3:         %{name}-2.9i-fix-bashisms.patch
BuildRequires:  flex
BuildRequires:  htdig-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libgnutls-devel
BuildRequires:  systemd
BuildRequires:  zlib-devel
Requires:       cron
%{?systemd_requires}

%description
A proxy HTTP server for computers with dial-up internet access.

%prep
%setup -q
%patch0
%patch1 -p1
%patch2 -p1
%patch3 -p1
# easier to delete them now and include whole doc directory later
rm -f doc/README.win32 doc/*/README.win32

%build
export LC_ALL=C
%configure \
  --with-confdir=%{_sysconfdir}/%{name} \
  --with-gcrypt \
  --with-gnutls \
  --with-ipv6 \
  --with-zlib
make %{?_smp_mflags}

%install
export LC_ALL=C
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}/%{_sysconfdir}/cron.{daily,weekly}
%make_install
install -m 755 %{SOURCE3} $RPM_BUILD_DIR
sed "s@%{_sysconfdir}/wwwoffle\\.conf@%{_sysconfdir}/wwwoffle/wwwoffle.conf@g" < doc/wwwoffled.man \
	> %{buildroot}%{_mandir}/man8/wwwoffled.8
install -D -m 0644 %{SOURCE1} %{buildroot}/%{_unitdir}/%{name}.service
ln -sf service %{buildroot}/%{_sbindir}/rc%{name}
install -d -m 755 %{buildroot}%{_localstatedir}/adm/fillup-templates
install -d -m 755 %{buildroot}%{_sysconfdir}/ppp/ip-{up,down}.d
install -m 755 %{SOURCE3} %{buildroot}/%{_sysconfdir}/ppp/ip-up.d/%{name}
install -m 755 %{SOURCE4} %{buildroot}/%{_sysconfdir}/ppp/ip-down.d/%{name}
install -m 644 %{SOURCE5} %{buildroot}/%{_sysconfdir}/cron.weekly/%{name}
# run as wwwrun:www by default
pushd %{buildroot}%{_sysconfdir}/%{name}
sed "s/^#run-uid.*/ run-uid           = wwwrun/
     s/^#run-gid.*/ run-gid           = www/" < %{name}.conf > %{name}.conf.t
mv %{name}.conf.t %{name}.conf
popd
rm -rf %{buildroot}%{_prefix}/doc/%{name}
rm -rf %{buildroot}%{_localstatedir}/spool/%{name}/outgoing/*
rm -f doc/ANNOUNCE~

%pre
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service

%post
%service_add_post %{name}.service

%postun
%service_del_postun %{name}.service

%files
%defattr(-, root, root)
# docs
%doc ChangeLog* contrib doc/*
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
# wwwoffle configs
%{_unitdir}/%{name}.service
%config(missingok,noreplace) %attr(755,root,root) %{_sysconfdir}/cron.weekly/%{name}
%dir %attr(750, wwwrun, root) %{_sysconfdir}/%{name}
%config %attr(640, wwwrun, root) %{_sysconfdir}/%{name}/%{name}.conf
%dir %{_localstatedir}/spool/%{name}/search/
# search configs for htdig
%dir %{_localstatedir}/spool/%{name}/search/htdig
%dir %{_localstatedir}/spool/%{name}/search/htdig/conf
%config(noreplace) %{_localstatedir}/spool/%{name}/search/htdig/conf/htfuzzy.conf
%config(noreplace) %{_localstatedir}/spool/%{name}/search/htdig/conf/htsearch.conf
%config(noreplace) %{_localstatedir}/spool/%{name}/search/htdig/conf/htdig-full.conf
%config(noreplace) %{_localstatedir}/spool/%{name}/search/htdig/conf/htdig-lasttime.conf
%config(noreplace) %{_localstatedir}/spool/%{name}/search/htdig/conf/htdig-incr.conf
%config(noreplace) %{_localstatedir}/spool/%{name}/search/htdig/conf/htmerge.conf
# search configs for mnogosearch
%dir %{_localstatedir}/spool/%{name}/search/mnogosearch
%dir %{_localstatedir}/spool/%{name}/search/mnogosearch/conf
%config(noreplace) %{_localstatedir}/spool/%{name}/search/mnogosearch/conf/indexer-full.old.conf
%config(noreplace) %{_localstatedir}/spool/%{name}/search/mnogosearch/conf/result.html
%config(noreplace) %{_localstatedir}/spool/%{name}/search/mnogosearch/conf/indexer-incr.old.conf
%config(noreplace) %{_localstatedir}/spool/%{name}/search/mnogosearch/conf/indexer-full.conf
%config(noreplace) %{_localstatedir}/spool/%{name}/search/mnogosearch/conf/indexer-incr.conf
# search configs for namazu
%dir %{_localstatedir}/spool/%{name}/search/namazu
%dir %{_localstatedir}/spool/%{name}/search/namazu/conf/
%config(noreplace) %{_localstatedir}/spool/%{name}/search/namazu/conf/mknmzrc
%config(noreplace) %{_localstatedir}/spool/%{name}/search/namazu/conf/namazurc
%dir %attr(750, wwwrun, root) %{_localstatedir}/spool/%{name}
%dir %{_localstatedir}/spool/%{name}/html
%doc %{_localstatedir}/spool/%{name}/html/*
%dir %attr(-, wwwrun, root) %{_localstatedir}/spool/%{name}/http
%dir %attr(-, wwwrun, root) %{_localstatedir}/spool/%{name}/lasttime
%dir %attr(-, wwwrun, root) %{_localstatedir}/spool/%{name}/monitor
%dir %attr(-, wwwrun, root) %{_localstatedir}/spool/%{name}/outgoing
%dir %attr(-, wwwrun, root) %{_localstatedir}/spool/%{name}/prevtime1
# rest of htdig
%{_localstatedir}/spool/%{name}/search/htdig/db
%{_localstatedir}/spool/%{name}/search/htdig/tmp
%{_localstatedir}/spool/%{name}/search/htdig/scripts
%{_localstatedir}/spool/%{name}/search/htdig/db-lasttime
# rest of mnogosearch
%{_localstatedir}/spool/%{name}/search/mnogosearch/db
%{_localstatedir}/spool/%{name}/search/mnogosearch/scripts
%{_localstatedir}/spool/%{name}/search/udmsearch
# rest of namazu
%{_localstatedir}/spool/%{name}/search/namazu/db
%{_localstatedir}/spool/%{name}/search/namazu/scripts
# hyperestraier
%{_localstatedir}/spool/%{name}/search/hyperestraier
%config(noreplace) %{_localstatedir}/spool/%{name}/search/hyperestraier/conf/estseek.conf
%{_bindir}/*
%{_sbindir}/*
%{_sysconfdir}/ppp/ip-up.d/%{name}
%{_sysconfdir}/ppp/ip-down.d/%{name}

%changelog
* Sat Feb 18 2017 mpluskal@suse.com
- Add missing dependency to enable https support
* Sat Feb 18 2017 tchvatal@suse.com
- Version update to 2.9j to fix bsc#1026023
  * Few crypto key length tweaks
  * Various small compilation warning fixes
- Refresh patch wwwoffle-2.9e-implicit.patch
* Sat Dec 13 2014 Led <ledest@gmail.com>
- fix bashisms in contrib/kppp scripts: 'read' command without
  arguments may be unsupported in other POSIX-complete shells
- add patches:
  * wwwoffle-2.9i-fix-bashisms.patch
* Sat Nov  8 2014 seife+obs@b1-systems.com
- fix reload target of service file (binary is in /usr/bin)
* Sun Nov  2 2014 tchvatal@suse.com
- Start service properly in daemon mode. Wrt bnc#903581.
* Mon May 12 2014 tchvatal@suse.com
- Update to 2.9i
  * Check the flex and lex programs are found by configure.
  * Allow https requests in outgoing to be requested when next online as https.
  * Don't detect webbugs for images with width and height set to auto.
  * Fix problem with infinite loop when root certificate expires.
- Run spec-cleaner on the package
- Provide service file instead of init script.
* Mon May 21 2012 badshah400@gmail.com
- Use BuildRequires: libgnutls-devel instead of gnutls-devel for
  Factory in keeping with gnutls package naming changes.
* Tue Oct  4 2011 vcizek@suse.com
- update to 2.9h
  * src/iognutls.c: Use the gnutls function to check for pending data
    first then use select() on the socket.
  * src/certificates.c: Create version 3 certificates instead of
    version 1.
  * src/io.c: Try and uncompress the data that is already available
    before asking for more data.
  * src/iognutls.c: Use the gnutls error message as the main error
    message if there is a gnutls error status (found during
    investigation of Debian bug deb#638595).
  * src/certificates.c: Free the server private keys and certificates
    at a different time and in a different way (see Debian bug
    deb#638595).
  * src/vrml.l, src/xml.l: Remove some gcc warning messages.
* Sun May  1 2011 chris@computersalat.de
- spec-cleanup
  o fix macros,...
  o remove author from description
* Mon Apr 11 2011 vcizek@novell.com
- update to 2.9g
  * src/testprogs/Makefile.in: Fixed Makefile for libgcrypt.
  * Check for libgnutls and libgcrypt separately at configure time.
  * Add a new option 'pass-url-unchanged' to not modify the outgoing
  URL from the browser to the server.
  * src/purge.c:
  Allow a one hour margin on the current time when warning about future timestamps
  and deleting temporary files (based on a patch from Michael Foerster).
  * src/certificates.c: Fix 2038 UNIX time_t problem.
* Fri Feb 26 2010 anicka@suse.cz
- update to 2.9f
  * Return a 304 reply if online and the cached page won't be
  refreshed and meets the conditions for this header.
  * Remove the use of the libgnutls-config program and search for the
  library in the normal configure script method.
  * When making a HEAD request use the cached version if possible.
  * Add a new option to the wwwoffle program to close and re-open
  the log file.
  * Add an option to expire certificates after a longer than
  default time.
  * Add an option to use a faster but weaker source of random numbers
  for key generation (/dev/urandom instead of /dev/random).
* Mon Feb 22 2010 anicka@suse.cz
- make wwwoffle to call res_init() when set online to avoid need
  of restarting to check for a new DNS (fixes bnc#467171)
* Sun Dec 20 2009 coolo@novell.com
- add fix from Marcus to fix build
* Tue Dec 15 2009 coolo@novell.com
- refresh patches to fix build
* Tue Jan 27 2009 kssingvo@suse.de
- Upgrade to version 2.9e:
  * Handle deflate compression errors
  * Don't allow wwwoffle to make requests that won't be got
  * Handle various encodings of URLs in HTML documents better
  * Display a note on the monitor form if the page is already monitored
  * Stopped an error message when refreshing while online
  * Several small fixes to documentation
- removed unnecessary README.win32 documents
* Wed Apr  9 2008 crrodriguez@suse.de
- missing zlib-devel and gnutls-devel in buildrequires
- wwwofle does not clean the proxy disk cache without cron, which is
  not installed by default, possible leading to a disk full problem
* Mon Jan 28 2008 kssingvo@suse.de
- Upgrade to version 2.9d:
  * src/html.l:
    Fetch image URLs stored in style attributes
  * src/certinfo.c:
    Print out the full certificate information
  * src/iozlib.c:
    Fix bug with decompressing zlib data.
  * src/certinfo.c:
    Remove the generation and display of the XML format certificate.
  * doc/README.CONF:
    Make the description of http-port and https-port options clearer.
  * src/spool.c:
    In case of failure to create directory check it hasn't been made
    simultaneously by another server.
  * doc/README.CONF, doc/wwwoffle.conf.man.template, src/config.h,
    src/configdata.c, src/document.h, src/html.l, src/info.c,
    src/refresh.c, src/wwwoffle.c, src/wwwoffle.h,
    conf/upgrade-config.pl, conf/wwwoffle.conf.template:
    Add a new option to the FetchOptions section called iframes.
  * conf/wwwoffle.conf.template, doc/README, doc/README.CONF,
    src/config.h, src/configdata.c, src/parse.c:
    Added a new option referer-from that will censor the outgoing
    Referer header based on the referring URL
  * src/htmlmodify.l:
    Don't output an extra space before an XHTML closing tag.
  * doc/README.CONF:
    Add some clarifications on IPv6 addresses in config file and how
    matching is performed.
- removed obsolete gcc patch (now in upstream code)
- fixed init script: requires $remote_fs now, as /usr might be one
* Tue Dec  4 2007 kssingvo@suse.de
- fix for next gcc: use open(2) with mode flags
* Mon Jul 30 2007 kssingvo@suse.de
- Upgrade to version 2.9c:
  * src/htmlmodify.l, src/html.l:
    Find the end of the script by searching for "</script".
  * src/certificates.c:
    Add some more information to the fatal error messages.
  * doc/README.CONF: Grammatical correction and clarification.
  * src/https.c: Don't try securing link if socket connection failed.
  * src/sockets6.c:
    Use the AI_ADDRCONFIG flag when calling getaddrinfo().
  * src/configmisc.c:
    Fix bug with case-insensitive wildcard matching in the
    configuration file
  * src/info.c: Fix some warnings & errors splint detected.
  * src/certificates.c, src/certinfo.c:
    Add some splint annotations, fix some warnings & errors splint
    detected.
  * src/certificates.h, src/iopriv.h, src/io.h:
    Add some splint annotations.
  * src/connect.c: Fix memory leak.
  * src/connect.c: Remove some dead code and trivial bug fix.
  * src/cgi.c, src/certinfo.c:
    More changes for compilation warnings on a system where
    size_t!=int
  * src/wwwoffles.c:
    Defer de-initialisation of chunked or compressed sockets
    until end to ensure memory is freed.
  * src/certinfo.c: Free memory.
  * src/certificates.c:
    De-initialise gnutls data structures to free memory.
  * src/finger.c: Make code same as http.c for opening socket
    connection.
  * src/info.c:
    Fix problems with cached page contents info if it is being
    stored compressed.
  * src/iopriv.c: Fix comment error.
  * src/wwwoffled.c:
    Print message when ready to start after initialisation.
  * src/document.c: Free allocated memory.
  * src/io.c: Free memory at file close.
  * src/certificates.c: Free memory at exit.
  * src/errors.c: Don't truncate the log file when opening it.
  * src/version.h, doc/NEWS: Update for version 2.9c.
* Thu Mar 29 2007 ro@suse.de
- added flex to buildreq
* Mon Feb 19 2007 kssingvo@suse.de
- Upgrade to version 2.9b:
  * doc/FAQ: Updated question about https
  * doc/README.CONF: Change wording of lock-files description
  * src/monitor.c: Display a non-empty value in the hour-of-day
    field for default setting
  * src/spool.c, src/errors.c, src/purge.c, src/certificates.c:
    Make sure that files are truncated when opening them.
  * src/io.c: Make sure that buffer size is OK.
  * src/html.l, src/htmlmodify.l: Fix HTML parsing of '\'
    characters outside strings (in script tags).
  * src/html.l, src/htmlmodify.l: Fix HTML parsing of '\'
    characters within quoted strings (in script tags and quoted
    HTML attributes).
  * src/iochunk.c, src/iopriv.c, src/iopriv.h, src/iozlib.c,
    src/io.c: Changes to allow turning zlib and chunked encoding
    off and returning to plain text. Fixed most of the FIXMEs in
    io.c.
  * src/certificates.c:
    Handle expired certificates by deleting them and creating a new
    one. If the root certificate is changed then it will need to be
    reloaded into the browser.
  * src/wwwoffles.c, src/spool.c:
    Don't delete the lasttime cached spool file if the page is
    unchanged this time but new sometime in this session.
  * src/spool.c: Make sure that allocated strings are long enough.
  * NEW: Expired SSL certificates are deleted and replaced.
- adapted (removed) integrated patch of SUSE/Novell.
* Wed Aug 23 2006 kssingvo@suse.de
- Upgrade to version 2.9a:
  * Keep attribute values that contain '()' but no quote characters.
  * Make more functions return ssize_t types.
  * Replace global function FindLanguageFile() with static function find_language_file().
  * Make sure that static functions are defined as static.
  * Correct some comments.
  * Fix code that mixed ssize_t and int variable types.
  * Remove the latest new header to keep IIS servers happy.
  * Make sure that allocated strings are long enough.
  * Remove any spaces between the header keyword and the ':'.
  * Remove misleading warning message.
  * Delete the 'Keep-Alive' header if it is present.
  * Add a new header to keep the 'bad-behaviour' PHP script happy.
  * Handle the special case of compressed chunk body of zero length.
  * Fix mis-formatting in wwwoffle.conf manual page created from README.CONF.
  * Change the behaviour of wwwoffle-ls so that 'wwwoffle-ls http://foo/' lists
    just the one URL and 'wwwoffle-ls http/foo' lists the whole directory.
  * Make the error messages about using /etc/wwwoffle/wwwoffle.conf instead
    of /etc/wwwoffle.conf less confusing (especially if CONFDIR = /etc).
  * Fix bug where a forced refresh didn't force a reload.
  * If a URL is aliased show the information for the alias.
  * Add an option to disable all iframes in HTML output.
  * Fix bug with serving CA certificate.
* Thu Aug 10 2006 seife@suse.de
- fix buffer overflow on "wwwoffle -fetch"
* Thu Aug 10 2006 seife@suse.de
- fix ip-up.wwwoffle: /sbin is not in the path
* Wed Jul 19 2006 kssingvo@suse.de
- fixed 64bit problem: difference in ssize_t
* Thu Jul 13 2006 kssingvo@suse.de
- fixed problems in ip-up/ip-down [bugzilla#191395]
- upgrade to version wwwoffle-2.9:
  o bug fixes
  o internal code changes
  o add a new layer of buffering to avoid large number of small network writes.
  o add checkboxes to protocol indexes (e.g. /index/http) for deleting multiple.
  o add reset button (and more if javascript) to clear delete checkboxes.
  o add the ability to use the Hyper Estraier programs to search the cache.
  o improve the purge output, print more information about what is happening.
  o move the convert-cache and uncompress-cache functions into wwwoffle-tools
* Tue Feb 28 2006 hvogel@suse.de
- fix files list [#115165]
* Fri Feb 17 2006 hvogel@suse.de
- clean up %%files section
- mark all config files [#115165]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 mmj@suse.de
- Update to wwwoffle-2.8e
* Fri Oct 21 2005 mmj@suse.de
- Install wwwoffle control files in /etc/ppp/if-{up,down}.d [#129452]
* Tue Sep  6 2005 mmj@suse.de
- Make wwwoffle be able to use htdig if it's there [#115165]
* Tue Apr 26 2005 mmj@suse.de
- Allocate enough room for const char *str
* Mon Dec 20 2004 mmj@suse.de
- Update to 2.8d
* Mon Jun 14 2004 mmj@suse.de
- Update to 2.8c which is a bugfix release
* Fri Dec  5 2003 mmj@suse.de
- Update to 2.8a
* Thu Oct 16 2003 mmj@suse.de
- Don't build as root
- Clean the specfile
* Thu Sep 18 2003 mmj@suse.de
- Make it not segfault on amd64 [#31327]
* Thu Jul 31 2003 poeml@suse.de
- since the configuration file and spool directory are owned by
  user wwwrun, run as wwwrun by default
- new macros for stop/restart of services on rpm update/removal
- let /var/spool/wwwoffle/{html,search} be owned by root
* Mon Jun  2 2003 schwab@suse.de
- Fix manpages.
- Fix links in translated index pages.
* Tue May 13 2003 mmj@suse.de
- Remove unwanted files, and package some missed ones
* Wed Jan 22 2003 mmj@suse.de
- Up to 2.7h which is a bugfix release with focus on security.
- Moved the config file back to /etc/wwwoffle/ since it makes bet-
  ter sense there [#23005]
* Wed Dec  4 2002 mmj@suse.de
- Up to 2.7g which is another minor bugfix release.
* Wed Oct  2 2002 mmj@suse.de
- Up to 2.7f mainly a bugfix-release. Fixes [#20432]
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Thu Aug 15 2002 mmj@suse.de
- Correct PreReq:
* Mon Jul 22 2002 mmj@suse.de
- Added security patch to parse.c, to check length correctly
* Tue Jul 16 2002 mmj@suse.de
- Update to 2.7c, bugfix and minor feature addition
* Mon Jul  8 2002 mmj@suse.de
- Fixing to start with /etc/wwwoffle.conf not /etc/wwwoffle
- Removed rc.config call in the init script.
* Mon May 13 2002 mmj@suse.de
- Update to 2.7b - including lots of new docs and switch to
  autoconf/automake. Also cgi script handling improved.
* Fri Dec 14 2001 ro@suse.de
- removed START_WWWOFFLE
* Thu Oct 11 2001 grimmer@suse.de
- fixed return code of the wwwoffle.cron script (cron sent
  a failure notice "SCRIPT: wwwoffle exited with RETURNCODE = 3"
  if the wwwoffled daemon was not running) [#11492]
* Wed Sep 19 2001 grimmer@suse.de
- Use "startproc -q" in rc.wwwoffle to suppress misleading
  warning messages ("Failed to bind IPv4 server socket [Address
  already in use]") [#10791]
- removed "chown -R wwwrun.root" in install section to enable
  non-root users to build the package as well (file ownerships
  are being properly set in the file list anyway)
* Thu Jul 26 2001 grimmer@suse.de
- Update to 2.6d: bugfixes and new features (e.g. IPv6 support)
- enabled IPv6 support and added required patch to sockets6.c
* Mon Jul 23 2001 grimmer@suse.de
- Update to 2.6c
* Mon Apr 23 2001 grimmer@suse.de
- Updated init file according to new skeleton
* Wed Apr  4 2001 grimmer@suse.de
- update to 2.6b
- removed Makefile patches (obsolete)
- added cron script as a separate source file
* Sun Feb 11 2001 grimmer@suse.de
- update to 2.6a
- added sample ip-up.local file to documentation directory (#6254)
- added upgrade-config scripts to file list
* Tue Jan 16 2001 grimmer@suse.de
- removed "noreplace" from config file /etc/wwwoffle/wwwoffle.conf
  since wwwoffle segfaults with an old config file after an
  update (#4940)
* Mon Dec 18 2000 grimmer@suse.de
- fixed path to ht://dig binaries
* Wed Dec  6 2000 grimmer@suse.de
- removed dependency on htdig and removed daily cron job
- fixed some typos in init script and spec file
- made weekly cron job more robust
- updated wwwoffle.test
* Thu Nov 30 2000 grimmer@suse.de
- Update to 2.6
- created new init script and moved it to /etc/init.d
- added BuildRoot
- use some more RPM macros
- added some more files and cron jobs
* Mon Jun 19 2000 grimmer@suse.de
- Update to 2.5e
* Thu Mar 30 2000 grimmer@suse.de
- fixed init script (reload is a real reload now) (#2650)
* Thu Feb 24 2000 grimmer@suse.de
- added Group tag
* Mon Feb 21 2000 grimmer@suse.de
- Update to 2.5d
- removed obsolete patch for errors.c
- moved man pages to /usr/share/man
* Tue Jan 25 2000 uli@suse.de
- errors.c: fixed misuse of va_arg macro
* Sat Oct  2 1999 grimmer@suse.de
- Update to 2.5
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jul  5 1999 grimmer@suse.de
- Update to 2.4e
- added docu in multiple languages to $DOCDIR
* Mon May 31 1999 grimmer@suse.de
- update to version 2.4d
* Tue Apr 13 1999 grimmer@suse.de
- update to version 2.4b
- specfile updates
- updated rc-script
* Wed Mar 24 1999 ro@suse.de
- fixed rc-script
* Tue Dec  8 1998 ro@suse.de
- fixed typo in rc-script
* Thu Nov  5 1998 grimmer@suse.de
- update to version 2.3e
- implemented new init script
- fixed script bug (shutdown with password)
* Mon Jul 20 1998 grimmer@suse.de
- changed CONFDIR again to /etc/wwwoffle/
- minor fix in init script rc.wwwoffle
* Sun Jul 19 1998 grimmer@suse.de
- update to version 2.2c
- changed CONFDIR back to /var/spool/
* Fri Jul  3 1998 bs@suse.de
- changed gid of /var/spool/wwwoffle from nogroup to root.
* Wed Jul  1 1998 grimmer@suse.de
- update to version 2.2
- updated init-script (reload, status)
- updated specfile (spoolfile,tools)
- changed CONFDIR to /etc
* Fri Apr  3 1998 bs@suse.de
- changed gid from nogroup to wwwadmin
* Tue Feb 17 1998 ro@suse.de
- update to version 2.0 (bb@suse.de)
* Fri Nov 14 1997 ro@suse.de
- fixed specfile (installation of docfiles)
* Mon Nov  3 1997 bb@suse.de
  new package!
